#include "PointList.h"
#include "DistanceCalculator.h"

PointList::PointList(const PointList& other) {
        DeepCopy(other);
}

PointList& PointList::operator=(const PointList& other) {
        if (this != &other) {
                for (auto point : m_points) {
                        delete point;
                }
                m_points.clear();
                DeepCopy(other);
        }
        return *this;
}

PointList::~PointList() {
        for (auto point : m_points) {
                delete point;
        }
}

void PointList::Add(Point& arg) {
        m_points.push_back(new Point(arg));
}

void PointList::Print() const {
        for (const auto point : m_points) {
                point->Print();
        }
}

double PointList::GetDistance() const {
        double totalDistance = 0.0;
        if (m_points.size() < 2) return totalDistance;

        DistanceCalculator* calculator = DistanceCalculator::GetInstance();
        for (size_t i = 0; i < m_points.size() - 1; ++i) {
                totalDistance += calculator->Distance(*m_points[i], *m_points[i + 1]);
        }
        return totalDistance;
}

void PointList::DeepCopy(const PointList& other) {
        for (const auto point : other.m_points) {
                m_points.push_back(new Point(*point));
        }
}
